@@ -34,7 +34,6 @@
 
 """Univention Configuration Registry backend for data storage."""
 
-from __future__ import print_function
 
 import errno
 import fcntl
@@ -42,25 +41,13 @@ import os
 import re
 import sys
 import time
+from collections.abc import Mapping, MutableMapping
 from enum import IntEnum
 from stat import S_ISREG
 
-
-try:
-    from collections.abc import Mapping, MutableMapping  # Python 3.3+
-except ImportError:
-    from collections import Mapping, MutableMapping  # type: ignore[attr-defined]
-
-import six
-
 from univention.config_registry.handler import run_filter
 
 
-if six.PY2:
-    from io import open
-
-    def overload(f):  # type ignore
-        pass
 try:
     from types import TracebackType  # noqa: F401
     from typing import overload  # noqa: F811
@@ -250,7 +237,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
             reg.load()
 
         self.autoload = Load.MANUAL  # prevent recursion!
-        strict = six.PY2 and self.is_true('ucr/encoding/strict')
+        strict = False  # self.is_true('ucr/encoding/strict')
         self.autoload = autoload
 
         for reg in self._registry.values():
@@ -306,8 +293,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         :returns: Iterator over all UCR variable names.
         """
         merge = self._merge()
-        for key in merge:
-            yield key
+        yield from merge
 
     def __len__(self):
         # type: () -> int
@@ -414,8 +400,6 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         except RuntimeError:  # maximum recursion depth exceeded
             value = b''
 
-        if six.PY2:
-            return value
         return value.decode("UTF-8")
 
     @overload
@@ -603,7 +587,7 @@ class _ConfigRegistry(dict):
                 if file_stat.st_mtime <= self.mtime and fn == self.file:
                     return
 
-                with open(fn, 'r', encoding='utf-8') as reg_file:
+                with open(fn, encoding='utf-8') as reg_file:
                     if reg_file.readline() == '' or reg_file.readline() == '':
                         continue
 
@@ -619,7 +603,7 @@ class _ConfigRegistry(dict):
                         new[key] = value.strip()
 
                 break
-            except EnvironmentError:
+            except OSError:
                 pass
         else:
             return
@@ -638,7 +622,7 @@ class _ConfigRegistry(dict):
         try:
             reg_file = os.open(self.file, os.O_CREAT | os.O_EXCL | os.O_WRONLY, 0o644)
             os.close(reg_file)
-        except EnvironmentError as ex:
+        except OSError as ex:
             if ex.errno == errno.EEXIST and not os.path.isdir(self.file):
                 return
             msg = "E: could not create file '%s': %s" % (self.file, ex)
@@ -659,7 +643,7 @@ class _ConfigRegistry(dict):
                 file_stat = os.stat(filename)
                 if not S_ISREG(file_stat.st_mode):
                     return
-            except EnvironmentError:
+            except OSError:
                 file_stat = os.stat_result((0o0644, -1, -1, -1, 0, 0, -1, -1, -1, -1))
 
             # open temporary file for writing
@@ -668,10 +652,10 @@ class _ConfigRegistry(dict):
                 os.chmod(temp_filename, file_stat.st_mode)
                 os.chown(temp_filename, file_stat.st_uid, file_stat.st_gid)
                 os.rename(temp_filename, filename)
-            except EnvironmentError as ex:
+            except OSError as ex:
                 if ex.errno == errno.EBUSY:
                     with open(filename, 'w+', encoding='utf-8') as fd:
-                        fd.write(open(temp_filename, 'r', encoding='utf-8').read())
+                        fd.write(open(temp_filename, encoding='utf-8').read())
                     os.unlink(temp_filename)
                 else:
                     # In this case the temp file created above in this
@@ -679,7 +663,7 @@ class _ConfigRegistry(dict):
                     # operation. Dump the current state to a backup file
                     temp_filename = '%s.concurrent_%s' % (filename, time.time())
                     self._save_to(temp_filename)
-        except EnvironmentError as ex:
+        except OSError as ex:
             # suppress certain errors
             if ex.errno != errno.EACCES:
                 raise
