@@ -35,15 +35,12 @@
 #
 # API stability :pylint: disable-msg=W0613
 # Rewrite       :pylint: disable-msg=R0912,R0914,R0915
-from __future__ import print_function
 
 import os
 import re
 import sys
 import time
 
-import six
-
 import univention.config_registry_info as cri
 from univention.config_registry.backend import SCOPE, ConfigRegistry, exception_occured
 from univention.config_registry.filters import filter_keys_only, filter_shell, filter_sort
@@ -52,8 +49,6 @@ from univention.config_registry.misc import escape_value, validate_key
 from univention.config_registry.validation import Type
 
 
-if six.PY2:
-    from io import open
 try:
     from typing import IO, Any, Callable, Dict, Iterator, List, NoReturn, Optional, Tuple  # noqa: F401
 except ImportError:  # pragma: no cover
@@ -128,7 +123,7 @@ def replog(ucr, var, old_value, value=None):
 
             with open(REPLOG_FILE, "a+", encoding='utf-8') as logfile:
                 logfile.write(log)
-        except EnvironmentError as ex:
+        except OSError as ex:
             print("E: exception occurred while writing to replication log: %s" % (ex,), file=sys.stderr)
             exception_occured()
 
@@ -305,8 +300,7 @@ def handler_dump(args, opts={}):
     """
     ucr = ConfigRegistry()
     ucr.load()
-    for line in str(ucr).split('\n'):
-        yield line
+    yield from str(ucr).split('\n')
 
 
 def handler_update(args, opts={}):
@@ -387,8 +381,7 @@ def handler_filter(args, opts={}):
     """Run filter on STDIN to STDOUT."""
     ucr = ConfigRegistry()
     ucr.load()
-    stdout = sys.stdout if six.PY2 else sys.stdout.buffer  # type: IO[bytes] # type: ignore
-    stdout.write(run_filter(sys.stdin.read(), ucr, opts=opts))
+    sys.stdout.buffer.write(run_filter(sys.stdin.read(), ucr, opts=opts))
 
 
 def handler_search(args, opts={}):
@@ -876,7 +869,7 @@ def main(args):
             for line in results:
                 print(line)
 
-    except (EnvironmentError, TypeError):
+    except (OSError, TypeError):
         if OPT_ACTIONS['debug'][1]:
             raise
         exception_occured()
