@@ -36,7 +36,6 @@
 """Handle UCR network configuration."""
 
 # pylint: disable-msg=W0142,C0103,R0201,R0904
-from __future__ import absolute_import
 
 import re
 from functools import wraps
@@ -335,8 +334,7 @@ class Interfaces(object):
     def all_interfaces(self):
         # type: () -> Iterator[Tuple[str, _Iface]]
         """Yield IPv4 interfaces."""
-        for name_settings in sorted(self._all_interfaces.items(), key=lambda name_iface: self._cmp_order(name_iface[1])):
-            yield name_settings
+        yield from sorted(self._all_interfaces.items(), key=lambda name_iface: self._cmp_order(name_iface[1]))
 
     @property
     def ipv4_interfaces(self):
