@@ -33,24 +33,15 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import print_function
 
 import os
 import re
 import string  # pylint: disable-msg=W0402
 import sys
+from shlex import quote as escape_value
+from typing import IO, Dict, List  # noqa: F401
 
 
-try:
-    from shlex import quote as escape_value
-except ImportError:
-    from pipes import quote as escape_value
-
-try:
-    from typing import IO, Dict, List, Text  # noqa: F401
-except ImportError:  # pragma: no cover
-    pass
-
 __all__ = [
     'INVALID_KEY_CHARS',
     'directory_files',
@@ -63,7 +54,7 @@ __all__ = [
 
 
 def replace_dict(line, dictionary):
-    # type: (Text, Dict[Text, str]) -> Text
+    # type: (str, Dict[str, str]) -> str
     """
     Map any character from line to its value from dictionary.
 
@@ -74,7 +65,7 @@ def replace_dict(line, dictionary):
 
 
 def replace_umlaut(line):
-    # type: (Text) -> Text
+    # type: (str) -> str
     u"""
     Replace german umlauts.
 
@@ -133,7 +124,7 @@ VALID_CHARS = (  # type: ignore # pylint: disable-msg=W0612
 
 
 def validate_key(key, out=sys.stderr):
-    # type: (Text, IO) -> bool
+    # type: (str, IO) -> bool
     """
     Check if key consists of only shell valid characters.
 
