@@ -5,7 +5,7 @@
 
 """Unit test for univention.config_registry."""
 
-import sys
+from importlib import reload
 from time import sleep
 
 import pytest
@@ -13,10 +13,6 @@ import pytest
 import univention.config_registry as UCR
 
 
-if sys.version_info >= (3,):
-    from importlib import reload
-
-
 def test_private(tmpucr):
     assert UCR.ucr_factory() is not UCR.ucr_factory()
 
